@@ -13,11 +13,11 @@ https://www.metas.ch/vnatools
 
 
 """
-from numpy import savetxt, array, hstack
+from numpy import array, hstack, savetxt
 
 from ..mathFunctions import complex2Scalar
-from ..networkSet import NetworkSet
 from ..network import average
+from ..networkSet import NetworkSet
 
 
 def ns_2_sdatcv(ns, fname, polar=False):
