@@ -4,6 +4,7 @@ import unittest
 import numpy as np
 from numpy.testing import assert_array_almost_equal
 
+from skrf.constants import S_DEF_DEFAULT
 from skrf.frequency import Frequency
 from skrf.media import DefinedGammaZ0
 from skrf.network import Network, concat_ports, connect
@@ -182,6 +183,53 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         ABCD[:,0,1] = Z
         assert_array_almost_equal(ABCD, ntwk.a)
 
+    def test_resistor_mismatch(self):
+        """
+        Compare the component values against s-parameters generated by QUCS.
+        The mismatch QUCS component is generated by renormalize() method.
+        """
+        # Config the qucs_ntwk and media
+        name = 'resistor,1ohm'
+        qucs_ntwk = Network(os.path.join(self.files_dir, name + '.s2p'))
+        self.dummy_media.frequency = qucs_ntwk.frequency
+        mismatch_z0_tuple = ([25, 50], [25-5j, 50+10j], [25, 50-10j])
+
+        # Test against Y-parameter defination
+        def resistor_y_def(media: DefinedGammaZ0, R, **kwargs):
+            result = media.match(nports=2, **kwargs)
+            y = np.zeros(shape=result.s.shape, dtype=complex)
+            R = np.array(R)
+            y[:, 0, 0] = 1.0 / R
+            y[:, 1, 1] = 1.0 / R
+            y[:, 0, 1] = -1.0 / R
+            y[:, 1, 0] = -1.0 / R
+            result.y = y
+            return result
+
+        # Test real and imag port impedance with Y-parameter defination and renormalize()
+        for mismatch_z0 in mismatch_z0_tuple:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0)
+            skrf_ntwk = self.dummy_media.resistor(1, name = name, z0=mismatch_z0)
+            skrf_ntwk_y = resistor_y_def(self.dummy_media, 1, z0=mismatch_z0)
+            self.assertEqual(qucs_ntwk_copy, skrf_ntwk)
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s)
+
+        # Config the s_def parameters
+        mismatch_z0 = [25, 50-10j]
+        s_defs = ("power", "pseudo", "traveling")
+
+        # Test different s_def configurations
+        for s_def in s_defs:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0, s_def=s_def)
+            skrf_ntwk = self.dummy_media.resistor(1, name=name, z0=mismatch_z0, s_def=s_def)
+            skrf_ntwk_y = resistor_y_def(self.dummy_media, 1, z0=mismatch_z0, s_def=s_def)
+            self.assertEqual(skrf_ntwk, qucs_ntwk_copy)
+            self.assertEqual(skrf_ntwk.s_def, qucs_ntwk_copy.s_def)
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s)
+            self.assertEqual(skrf_ntwk.s_def, skrf_ntwk_y.s_def)
+
     def test_shunt_resistor(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -218,6 +266,54 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         ABCD[:,0,1] = Z
         assert_array_almost_equal(ABCD, ntwk.a)
 
+    def test_capacitor_mismatch(self):
+        """
+        Compare the component values against s-parameters generated by QUCS.
+        The mismatch QUCS component is generated by renormalize() method.
+        """
+        # Config the qucs_ntwk and media
+        name = 'capacitor,p01pF'
+        qucs_ntwk = Network(os.path.join(self.files_dir, name + '.s2p'))
+        self.dummy_media.frequency = qucs_ntwk.frequency
+        mismatch_z0_tuple = ([25, 50], [25-5j, 50+10j], [25, 50-10j])
+
+        # Test against Y-parameter defination
+        def capacitor_y_def(media: DefinedGammaZ0, C, **kwargs):
+            result = media.match(nports=2, **kwargs)
+            w = media.frequency.w
+            y = np.zeros(shape=result.s.shape, dtype=complex)
+            C = np.array(C)
+            y[:, 0, 0] = 1j * w * C
+            y[:, 1, 1] = 1j * w * C
+            y[:, 0, 1] = -1j * w * C
+            y[:, 1, 0] = -1j * w * C
+            result.y = y
+            return result
+
+        # Test real and imag port impedance with Y-parameter defination and renormalize()
+        for mismatch_z0 in mismatch_z0_tuple:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0)
+            skrf_ntwk = self.dummy_media.capacitor(.01e-12, name = name, z0=mismatch_z0)
+            skrf_ntwk_y = capacitor_y_def(self.dummy_media, .01e-12, z0=mismatch_z0)
+            self.assertEqual(qucs_ntwk_copy, skrf_ntwk)
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s)
+
+        # Config the s_def parameters
+        mismatch_z0 = [25, 50-10j]
+        s_defs = ("power", "pseudo", "traveling")
+
+        # Test different s_def configurations
+        for s_def in s_defs:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0, s_def=s_def)
+            skrf_ntwk = self.dummy_media.capacitor(.01e-12, name=name, z0=mismatch_z0, s_def=s_def)
+            skrf_ntwk_y = capacitor_y_def(self.dummy_media, .01e-12, z0=mismatch_z0, s_def=s_def)
+            self.assertEqual(skrf_ntwk, qucs_ntwk_copy)
+            self.assertEqual(skrf_ntwk.s_def, qucs_ntwk_copy.s_def)
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s)
+            self.assertEqual(skrf_ntwk.s_def, skrf_ntwk_y.s_def)
+
     def test_shunt_capacitor(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -285,6 +381,55 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         ABCD[:,0,1] = Z
         assert_array_almost_equal(ABCD, ntwk.a)
 
+    def test_inductor_mismatch(self):
+        """
+        Compare the component values against s-parameters generated by QUCS.
+        The mismatch QUCS component is generated by renormalize() method.
+        """
+        # Config the qucs_ntwk and media
+        name = 'inductor,p1nH'
+        qucs_ntwk = Network(os.path.join(self.files_dir, name + '.s2p'))
+        self.dummy_media.frequency = qucs_ntwk.frequency
+        mismatch_z0_tuple = ([25, 50], [25-5j, 50+10j], [25, 50-10j])
+
+        # Test against Y-parameter defination
+        def inductor_y_def(media: DefinedGammaZ0, L, **kwargs):
+            result = media.match(nports=2, **kwargs)
+            w = media.frequency.w
+            y = np.zeros(shape=result.s.shape, dtype=complex)
+            L = np.array(L)
+            y[:, 0, 0] = 1.0 / (1j * w * L)
+            y[:, 1, 1] = 1.0 / (1j * w * L)
+            y[:, 0, 1] = -1.0 / (1j * w * L)
+            y[:, 1, 0] = -1.0 / (1j * w * L)
+            result.y = y
+            return result
+
+        # Test real and imag port impedance with Y-parameter defination and renormalize()
+        for mismatch_z0 in mismatch_z0_tuple:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0)
+            skrf_ntwk = self.dummy_media.inductor(.1e-9, name = name, z0=mismatch_z0)
+            skrf_ntwk_y = inductor_y_def(self.dummy_media, .1e-9, z0=mismatch_z0)
+            self.assertEqual(qucs_ntwk_copy, skrf_ntwk)
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s)
+
+        # Config the s_def parameters
+        mismatch_z0 = [25, 50-10j]
+        s_defs = ("power", "pseudo", "traveling")
+
+        # Test different s_def configurations
+        for s_def in s_defs:
+            qucs_ntwk_copy = qucs_ntwk.copy()
+            qucs_ntwk_copy.renormalize(mismatch_z0, s_def=s_def)
+            skrf_ntwk = self.dummy_media.inductor(.1e-9, name=name, z0=mismatch_z0, s_def=s_def)
+            skrf_ntwk_y = inductor_y_def(self.dummy_media, .1e-9, z0=mismatch_z0, s_def=s_def)
+            self.assertEqual(skrf_ntwk, qucs_ntwk_copy)
+            self.assertEqual(skrf_ntwk.s_def, qucs_ntwk_copy.s_def)
+            # numerical precision is slightly reduced when using pseudo s_def
+            assert_array_almost_equal(skrf_ntwk.s, skrf_ntwk_y.s, decimal={'pseudo': 5}.get(s_def, 6))
+            self.assertEqual(skrf_ntwk.s_def, skrf_ntwk_y.s_def)
+
     def test_shunt_inductor(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -391,6 +536,52 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
             zero_length = self.dummy_media.line_floating(d=0, z0=z0)
             assert_array_almost_equal(zero_length.s, s_zero)
 
+    def test_line_floating2(self):
+        """
+        Test against line
+        """
+        d = 100
+        unit = 'mm'
+        z0 = 50
+        line = self.dummy_media.line(d, unit, z0)
+        line_floating = self.dummy_media.line_floating(d, unit, z0)
+        gnd = self.dummy_media.short(n_ports=1)
+        line_floating = connect(line_floating, 3, gnd, 0)
+        line_floating = connect(line_floating, 2, gnd, 0)
+        assert_array_almost_equal(line_floating.s, line.s)
+
+    def test_line_floating3(self):
+        """
+        Test against Y-parameter definition
+        """
+        d = 100
+        unit = 'mm'
+
+        def yparam_ref(media, d, unit, z0, s_def=S_DEF_DEFAULT):
+            result = media.match(nports=4, z0=z0, s_def='traveling')
+
+            theta = media.electrical_length(media.to_meters(d=d, unit=unit))
+
+            # From AWR docs on TLINP4.
+            y11 = 1 / (z0 * np.tanh(theta))
+            y12 = -1 / (z0 * np.sinh(theta))
+            y22 = y11
+            y21 = y12
+
+            result.y = \
+                    np.array([[ y11,  y12, -y11, -y12],
+                              [ y21,  y22, -y21, -y22],
+                              [-y11, -y12,  y11,  y12],
+                              [-y21, -y22,  y21,  y22]]).transpose(2,0,1)
+            if media.z0_port is not None:
+                result.renormalize(media.z0_port)
+            result.renormalize(result.z0, s_def=s_def)
+            return result
+
+        for z0 in [50, 1, 100+10j]:
+            line = self.dummy_media.line_floating(d, unit, z0)
+            ref_line = yparam_ref(self.dummy_media, d, unit, z0)
+            assert_array_almost_equal(ref_line.s, line.s)
 
     def test_scalar_gamma_z0_media(self):
         """
