@@ -24,11 +24,14 @@ References
     Klopfenstein
 
 """
+from __future__ import annotations
 
 from numbers import Number
-from typing import Callable, List
-from . network import cascade_list
-from numpy import exp, log, linspace
+from typing import Callable
+
+from numpy import exp, linspace, log
+
+from .network import cascade_list
 
 
 class Taper1D:
@@ -37,7 +40,7 @@ class Taper1D:
     """
     def __init__(self, med, start: Number, stop: Number, n_sections: int, f: Callable,
                  length: Number, length_unit: str = 'm', param: str = 'z0', f_is_normed: bool = True,
-                 med_kw: dict = {}, f_kw: dict = {}):
+                 med_kw: dict = None, f_kw: dict = None):
         """
         Generic 1D Taper Constructor.
 
@@ -102,6 +105,10 @@ class Taper1D:
                             f_is_normed=True,
                             med_kw={'frequency':Frequency(75,110,101,'ghz')})
         """
+        if f_kw is None:
+            f_kw = {}
+        if med_kw is None:
+            med_kw = {}
         self.med = med
         self.param = param
         self.start = start
@@ -121,7 +128,7 @@ class Taper1D:
         # it makes for a intuitive operation
         if param == 'z0':
             if hasattr(self.med, 'from_z0'):
-                self.med = getattr(self.med, 'from_z0')
+                self.med = self.med.from_z0
 
     def __str__(self) -> str:
         return 'Taper: {classname}: {param} from {start}-{stop}'
@@ -185,7 +192,7 @@ class Taper1D:
                                        unit=self.length_unit)
 
     @property
-    def medias(self) -> List:
+    def medias(self) -> list:
         """
         List of medias.
 
@@ -196,7 +203,7 @@ class Taper1D:
         return [self.media_at(k) for k in self.value_vector]
 
     @property
-    def sections(self) -> List:
+    def sections(self) -> list:
         """
         List of sections.
 
@@ -300,7 +307,8 @@ class Klopfenstein(Taper1D):
         doi: 10.1109/JRPROC.1956.274847
         https://ieeexplore.ieee.org/document/4051841
     .. [#Kajfez] D. Kajfez and J. O. Prewitt, "Correction to "A Transmission Line Taper of Improved Design" (Letters),"
-        in IEEE Transactions on Microwave Theory and Techniques, vol. 21, no. 5, pp. 364-364, May 1973, doi: 10.1109/TMTT.1973.1128003.
+        in IEEE Transactions on Microwave Theory and Techniques, vol. 21, no. 5, pp. 364-364, May 1973,
+        doi: 10.1109/TMTT.1973.1128003.
         https://ieeexplore.ieee.org/document/1128003
     """
     def __init__(self, **kw):
