@@ -329,6 +329,7 @@ class NetworkTestCase(unittest.TestCase):
             sio.name = os.path.basename(filename) # hack a bug to touchstone reader
             rf.Network(sio)
 
+    def test_constructor_from_stringio_hfss(self):
         filename = os.path.join(self.test_dir, 'hfss_oneport.s1p')
         with open(filename) as fid:
             data = fid.read()
@@ -336,6 +337,13 @@ class NetworkTestCase(unittest.TestCase):
             sio.name = os.path.basename(filename) # hack a bug to touchstone reader
             rf.Network(sio)
 
+    def test_constructor_from_stringio_name_kwawrg(self):
+        filename = os.path.join(self.test_dir, 'ntwk1.s2p')
+        with open(filename) as fid:
+            data = fid.read()
+            sio = io.StringIO(data)
+            rf.Network(sio, name=filename)
+
     def test_different_ext(self):
         filename= os.path.join(self.test_dir, 'ntwk1.s2p')
         for par in ["g", "h", "s", "y", "z"]:
